@@ -1,9 +1,10 @@
 import github3
+from .helper import create_example_data_helper
+from .helper import UnitHelper
 
-from .helper import (UnitHelper, create_example_data_helper)
-
-get_combined_status_example_data = \
-    create_example_data_helper('repos_combined_status_example')
+get_combined_status_example_data = create_example_data_helper(
+    "repos_combined_status_example"
+)
 
 
 class TestCombinedStatus(UnitHelper):
@@ -14,7 +15,7 @@ class TestCombinedStatus(UnitHelper):
     example_data = get_combined_status_example_data()
 
     def test_repr(self):
-        assert repr(self.instance).startswith('<CombinedStatus')
+        assert repr(self.instance).startswith("<CombinedStatus")
 
     def test_statuses(self):
         assert len(self.instance.statuses) == self.instance.total_count
